@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,8 +26,7 @@
 #include <QTextImageFormat>
 #include <QSharedPointer>
 #include "kpimtextedit_export.h"
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class RichTextComposer;
 /**
  * Holds information about an embedded HTML image that will be useful for mail clients.
@@ -58,7 +57,7 @@ class KPIMTEXTEDIT_EXPORT RichTextComposerImages : public QObject
 {
     Q_OBJECT
 public:
-    explicit RichTextComposerImages(RichTextComposer *composer, QObject *parent = Q_NULLPTR);
+    explicit RichTextComposerImages(RichTextComposer *composer, QObject *parent = nullptr);
     ~RichTextComposerImages();
 
     /**
